@@ -38,6 +38,40 @@
 
 #define BLOCK_HANDLER_ID "block-handler-id"
 
+/*****************************************************************************/
+
+static const char *comp_lzo_values[] = {
+	"adaptive",
+	"yes",
+	"no-by-default",
+};
+
+static const char *
+comp_lzo_values_conf_coerce (const char *value_conf)
+{
+	if (!value_conf || nm_streq (value_conf, "no"))
+		return NULL;
+	if (nm_streq (value_conf, "yes"))
+		return "yes";
+	if (nm_streq (value_conf, "no-by-default"))
+		return "no-by-default";
+	return "adaptive";
+}
+
+static const char *
+comp_lzo_values_conf_to_display (const char *value_conf)
+{
+	if (nm_streq (value_conf, "yes"))
+		return "yes";
+	if (nm_streq (value_conf, "no-by-default"))
+		return "no";
+	if (nm_streq (value_conf, "adaptive"))
+		return "adaptive";
+	g_return_val_if_reached ("adaptive");
+}
+
+/*****************************************************************************/
+
 static void
 show_password (GtkToggleButton *togglebutton, GtkEntry *password_entry)
 {
@@ -906,6 +940,7 @@ static const char *advanced_keys[] = {
 	NM_OPENVPN_KEY_AUTH,
 	NM_OPENVPN_KEY_TA_DIR,
 	NM_OPENVPN_KEY_TA,
+	NM_OPENVPN_KEY_TLS_CRYPT,
 	NM_OPENVPN_KEY_RENEG_SECONDS,
 	NM_OPENVPN_KEY_TLS_REMOTE,
 	NM_OPENVPN_KEY_VERIFY_X509_NAME,
@@ -917,6 +952,7 @@ static const char *advanced_keys[] = {
 	NM_OPENVPN_KEY_PING_EXIT,
 	NM_OPENVPN_KEY_PING_RESTART,
 	NM_OPENVPN_KEY_MAX_ROUTES,
+	NM_OPENVPN_KEY_MTU_DISC,
 	NULL
 };
 
@@ -1211,7 +1247,7 @@ populate_tls_remote_mode_entry_combo (GtkEntry* entry, GtkComboBox *box,
 
 	gtk_list_store_append (store, &iter);
 	gtk_list_store_set (store, &iter,
-	                    TLS_REMOTE_MODE_COL_NAME, _("Verify subject partially (legacy mode)"),
+	                    TLS_REMOTE_MODE_COL_NAME, _("Verify subject partially (legacy mode, strongly discouraged)"),
 	                    TLS_REMOTE_MODE_COL_VALUE, TLS_REMOTE_MODE_LEGACY,
 	                    -1);
 
@@ -1250,6 +1286,7 @@ tls_remote_changed (GtkWidget *widget, gpointer user_data)
 	GtkWidget *entry, *combo, *ok_button;
 	GtkTreeIter iter;
 	gboolean entry_enabled = TRUE, entry_has_error = FALSE;
+	gboolean legacy_tls_remote = FALSE;
 
 	entry     = GTK_WIDGET (gtk_builder_get_object (builder, "tls_remote_entry"));
 	combo     = GTK_WIDGET (gtk_builder_get_object (builder, "tls_remote_mode_combo"));
@@ -1272,6 +1309,7 @@ tls_remote_changed (GtkWidget *widget, gpointer user_data)
 
 			entry_enabled = TRUE;
 			entry_has_error = !subject || !subject[0];
+			legacy_tls_remote = nm_streq (tls_remote_mode, TLS_REMOTE_MODE_LEGACY);
 		}
 	}
 
@@ -1280,9 +1318,17 @@ tls_remote_changed (GtkWidget *widget, gpointer user_data)
 		widget_set_error (entry);
 		gtk_widget_set_sensitive (ok_button, FALSE);
 	} else {
-		widget_unset_error (entry);
+		if (legacy_tls_remote) {
+			/* selecting tls-remote is not an error, but strongly discouraged. I wish
+			 * there would be a warning-class as well. Anyway, mark the widget as
+			 * erroneous, although this doesn't make the connection invalid (which
+			 * is an ugly inconsistency). */
+			widget_set_error (entry);
+		} else
+			widget_unset_error (entry);
 		gtk_widget_set_sensitive (ok_button, TRUE);
 	}
+
 }
 
 static void
@@ -1332,23 +1378,28 @@ populate_remote_cert_tls_combo (GtkComboBox *box, const char *remote_cert)
 	g_object_unref (store);
 }
 
+#define TLS_AUTH_MODE_NONE  0
+#define TLS_AUTH_MODE_AUTH  1
+#define TLS_AUTH_MODE_CRYPT 2
+
 static void
 tls_auth_toggled_cb (GtkWidget *widget, gpointer user_data)
 {
 	GtkBuilder *builder = (GtkBuilder *) user_data;
-	gboolean use_auth = FALSE;
+	gint active;
 
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_checkbutton"));
-	use_auth = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_mode"));
+	active = gtk_combo_box_get_active (GTK_COMBO_BOX (widget));
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "direction_label"));
-	gtk_widget_set_sensitive (widget, use_auth);
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_label"));
-	gtk_widget_set_sensitive (widget, use_auth);
-	widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_chooser"));
-	gtk_widget_set_sensitive (widget, use_auth);
+	gtk_widget_set_sensitive (widget, active == TLS_AUTH_MODE_AUTH);
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "direction_combo"));
-	gtk_widget_set_sensitive (widget, use_auth);
+	gtk_widget_set_sensitive (widget, active == TLS_AUTH_MODE_AUTH);
+
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_label"));
+	gtk_widget_set_sensitive (widget, active != TLS_AUTH_MODE_NONE);
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_chooser"));
+	gtk_widget_set_sensitive (widget, active != TLS_AUTH_MODE_NONE);
 }
 
 static void
@@ -1398,6 +1449,19 @@ populate_ns_cert_type_combo (GtkComboBox *box, const char *type)
 	g_object_unref (store);
 }
 
+static void
+mtu_disc_toggled_cb (GtkWidget *widget, gpointer user_data)
+{
+	GtkBuilder *builder = (GtkBuilder *) user_data;
+	gboolean use_mtu_disc;
+
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "mtu_disc_checkbutton"));
+	use_mtu_disc = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
+
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "mtu_disc_combo"));
+	gtk_widget_set_sensitive (widget, use_mtu_disc);
+}
+
 #define PROXY_TYPE_NONE  0
 #define PROXY_TYPE_HTTP  1
 #define PROXY_TYPE_SOCKS 2
@@ -1559,7 +1623,7 @@ _hash_get_boolean (GHashTable *hash,
 	return nm_streq0 (value, "yes");
 }
 
-static void
+static GtkToggleButton *
 _builder_init_toggle_button (GtkBuilder *builder,
                              const char *widget_name,
                              gboolean active_state)
@@ -1567,9 +1631,10 @@ _builder_init_toggle_button (GtkBuilder *builder,
 	GtkToggleButton *widget;
 
 	widget = (GtkToggleButton *) gtk_builder_get_object (builder, widget_name);
-	g_return_if_fail (GTK_IS_TOGGLE_BUTTON (widget));
+	g_return_val_if_fail (GTK_IS_TOGGLE_BUTTON (widget), NULL);
 
 	gtk_toggle_button_set_active (widget, active_state);
+	return widget;
 }
 
 static void
@@ -1623,6 +1688,7 @@ advanced_dialog_new (GHashTable *hash, const char *contype)
 	const char *dev, *dev_type, *tap_dev;
 	GtkListStore *store;
 	GtkTreeIter iter;
+	guint i;
 	guint32 active;
 	guint32 pw_flags = NM_SETTING_SECRET_FLAG_NONE;
 	GError *error = NULL;
@@ -1750,13 +1816,23 @@ advanced_dialog_new (GHashTable *hash, const char *contype)
 	                                   _nm_utils_ascii_str_to_int64 (value, 10, 0, 65535, 1300));
 
 
-	/* the UI currently only supports "--comp-lzo yes" or omitting the "--comp-lzo"
-	 * flag.
-	 *
-	 * Internally, we also support "--comp-lzo [adaptive]" and "--comp-lzo no"
-	 * which have different meaning for openvpn. */
-	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_COMP_LZO);
-	_builder_init_toggle_button (builder, "lzo_checkbutton", NM_IN_STRSET (value, "yes", "adaptive"));
+	value = comp_lzo_values_conf_coerce (g_hash_table_lookup (hash, NM_OPENVPN_KEY_COMP_LZO));
+	widget = GTK_WIDGET (_builder_init_toggle_button (builder, "lzo_checkbutton", value != NULL));
+	combo = GTK_WIDGET (gtk_builder_get_object (builder, "lzo_combo"));
+	store = gtk_list_store_new (1, G_TYPE_STRING);
+	active = 0;
+	for (i = 0; i < G_N_ELEMENTS (comp_lzo_values); i++) {
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter,
+		                    0, comp_lzo_values_conf_to_display (comp_lzo_values[i]),
+		                    -1);
+		if (nm_streq (comp_lzo_values[i], value ?: "adaptive"))
+			active = i;
+	}
+	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+	g_object_unref (store);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), active);
+	g_object_bind_property (widget, "active", combo, "sensitive", G_BINDING_SYNC_CREATE);
 
 	_builder_init_toggle_button (builder, "mssfix_checkbutton", _hash_get_boolean (hash, NM_OPENVPN_KEY_MSSFIX));
 	_builder_init_toggle_button (builder, "float_checkbutton", _hash_get_boolean (hash, NM_OPENVPN_KEY_FLOAT));
@@ -1844,52 +1920,49 @@ advanced_dialog_new (GHashTable *hash, const char *contype)
 	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_NS_CERT_TYPE);
 	populate_ns_cert_type_combo (GTK_COMBO_BOX (widget), value);
 
-	if (   !strcmp (contype, NM_OPENVPN_CONTYPE_TLS)
-	    || !strcmp (contype, NM_OPENVPN_CONTYPE_PASSWORD_TLS)
-	    || !strcmp (contype, NM_OPENVPN_CONTYPE_PASSWORD)) {
+	if (NM_IN_STRSET (contype,
+	                  NM_OPENVPN_CONTYPE_TLS,
+	                  NM_OPENVPN_CONTYPE_PASSWORD_TLS,
+	                  NM_OPENVPN_CONTYPE_PASSWORD)) {
 		int direction = -1;
 
-		active = 0;
-		widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_checkbutton"));
-		value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_TA);
-		if (value && strlen (value))
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
-		g_signal_connect (G_OBJECT (widget), "toggled", G_CALLBACK (tls_auth_toggled_cb), builder);
-		tls_auth_toggled_cb (widget, builder);
-
-		widget = GTK_WIDGET (gtk_builder_get_object (builder, "direction_combo"));
-		value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_TA_DIR);
-		if (value && strlen (value)) {
-			direction = (int) strtol (value, NULL, 10);
-			/* If direction is not 0 or 1, use no direction */
-			if (direction != 0 && direction != 1)
-				direction = -1;
-		}
-
+		/* Initialize direction combo */
+		combo = GTK_WIDGET (gtk_builder_get_object (builder, "direction_combo"));
 		store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
-
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter, TA_DIR_COL_NAME, _("None"), TA_DIR_COL_NUM, -1, -1);
-
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter, TA_DIR_COL_NAME, "0", TA_DIR_COL_NUM, 0, -1);
-		if (direction == 0)
-			active = 1;
-
 		gtk_list_store_append (store, &iter);
 		gtk_list_store_set (store, &iter, TA_DIR_COL_NAME, "1", TA_DIR_COL_NUM, 1, -1);
-		if (direction == 1)
-			active = 2;
-
-		gtk_combo_box_set_model (GTK_COMBO_BOX (widget), GTK_TREE_MODEL (store));
+		gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
 		g_object_unref (store);
-		gtk_combo_box_set_active (GTK_COMBO_BOX (widget), active);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 
+		combo = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_mode"));
+		widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_chooser"));
 		value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_TA);
-		if (value && strlen (value)) {
-			widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_chooser"));
+		value2 = g_hash_table_lookup (hash, NM_OPENVPN_KEY_TLS_CRYPT);
+		if (value2 && value2[0]) {
+			gtk_combo_box_set_active (GTK_COMBO_BOX (combo), TLS_AUTH_MODE_CRYPT);
+			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (widget), value2);
+		} else if (value && value[0]) {
+			gtk_combo_box_set_active (GTK_COMBO_BOX (combo), TLS_AUTH_MODE_AUTH);
 			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (widget), value);
-		}
+			value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_TA_DIR);
+			if (value && value[0]) {
+				direction = (int) strtol (value, NULL, 10);
+				/* If direction is not 0 or 1, use no direction */
+				if (direction != 0 && direction != 1)
+					direction = -1;
+			}
+			widget = GTK_WIDGET (gtk_builder_get_object (builder, "direction_combo"));
+			gtk_combo_box_set_active (GTK_COMBO_BOX (widget), direction + 1);
+		} else
+			gtk_combo_box_set_active (GTK_COMBO_BOX (combo), TLS_AUTH_MODE_NONE);
+
+		g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (tls_auth_toggled_cb), builder);
+		tls_auth_toggled_cb (combo, builder);
 	} else {
 		widget = GTK_WIDGET (gtk_builder_get_object (builder, "options_notebook"));
 		gtk_notebook_remove_page (GTK_NOTEBOOK (widget), 2);
@@ -1930,6 +2003,21 @@ advanced_dialog_new (GHashTable *hash, const char *contype)
 	gtk_widget_set_sensitive (spin, !!value);
 	gtk_toggle_button_set_active ((GtkToggleButton *) widget, !!value);
 
+	/* MTU discovery */
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "mtu_disc_checkbutton"));
+	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_MTU_DISC);
+	if (value && value[0]) {
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
+		combo = GTK_WIDGET (gtk_builder_get_object (builder, "mtu_disc_combo"));
+		if (nm_streq (value, "maybe"))
+			gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 1);
+		else if (nm_streq (value, "yes"))
+			gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 2);
+		else
+			gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+	}
+	g_signal_connect (G_OBJECT (widget), "toggled", G_CALLBACK (mtu_disc_toggled_cb), builder);
+	mtu_disc_toggled_cb (widget, builder);
 
 	value = g_hash_table_lookup (hash, NM_OPENVPN_KEY_MAX_ROUTES);
 	_builder_init_optional_spinbutton (builder, "max_routes_checkbutton", "max_routes_spinbutton", !!value,
@@ -1949,6 +2037,7 @@ advanced_dialog_new_hash_from_dialog (GtkWidget *dialog, GError **error)
 	GtkBuilder *builder;
 	const char *contype = NULL;
 	const char *value;
+	int active;
 	int proxy_type = PROXY_TYPE_NONE;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
@@ -2056,13 +2145,10 @@ advanced_dialog_new_hash_from_dialog (GtkWidget *dialog, GError **error)
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "lzo_checkbutton"));
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
-		/* we only have a checkbox, which we either map to "--comp-lzo yes" or
-		 * no "--comp-lzo" flag. In the UI, we cannot express "--comp-lzo [adaptive]"
-		 * or "--comp-lzo no".
-		 *
-		 * Note that "--comp-lzo no" must be encoded as "comp-lzo=no-by-default" (bgo#769177).
-		 */
-		g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_COMP_LZO), g_strdup ("yes"));
+		combo = GTK_WIDGET (gtk_builder_get_object (builder, "lzo_combo"));
+		active = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+		if (active >= 0 && active < G_N_ELEMENTS (comp_lzo_values))
+			g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_COMP_LZO), g_strdup (comp_lzo_values[active]));
 	}
 
 	widget = GTK_WIDGET (gtk_builder_get_object (builder, "mssfix_checkbutton"));
@@ -2142,6 +2228,7 @@ advanced_dialog_new_hash_from_dialog (GtkWidget *dialog, GError **error)
 	if (   !strcmp (contype, NM_OPENVPN_CONTYPE_TLS)
 	    || !strcmp (contype, NM_OPENVPN_CONTYPE_PASSWORD_TLS)
 	    || !strcmp (contype, NM_OPENVPN_CONTYPE_PASSWORD)) {
+		char *filename;
 
 		entry = GTK_WIDGET (gtk_builder_get_object (builder, "tls_remote_entry"));
 		value = gtk_entry_get_text (GTK_ENTRY (entry));
@@ -2193,15 +2280,13 @@ advanced_dialog_new_hash_from_dialog (GtkWidget *dialog, GError **error)
 			}
 		}
 
-		widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_checkbutton"));
-		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
-			char *filename;
-
+		combo = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_mode"));
+		switch (gtk_combo_box_get_active (GTK_COMBO_BOX (combo))) {
+		case TLS_AUTH_MODE_AUTH:
 			widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_chooser"));
 			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
-			if (filename && strlen (filename)) {
+			if (filename && filename[0])
 				g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_TA), g_strdup (filename));
-			}
 			g_free (filename);
 
 			widget = GTK_WIDGET (gtk_builder_get_object (builder, "direction_combo"));
@@ -2215,10 +2300,20 @@ advanced_dialog_new_hash_from_dialog (GtkWidget *dialog, GError **error)
 					                     g_strdup_printf ("%d", direction));
 				}
 			}
+			break;
+		case TLS_AUTH_MODE_CRYPT:
+			widget = GTK_WIDGET (gtk_builder_get_object (builder, "tls_auth_chooser"));
+			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (widget));
+			if (filename && filename[0])
+				g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_TLS_CRYPT), g_strdup (filename));
+			g_free (filename);
+			break;
+		case TLS_AUTH_MODE_NONE:
+			break;
 		}
 	}
 
-        widget = GTK_WIDGET (gtk_builder_get_object (builder, "ping_checkbutton"));
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "ping_checkbutton"));
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
 		int ping_val;
 
@@ -2257,6 +2352,30 @@ advanced_dialog_new_hash_from_dialog (GtkWidget *dialog, GError **error)
 		g_hash_table_insert (hash, g_strdup (NM_OPENVPN_KEY_MAX_ROUTES), g_strdup_printf ("%d", max_routes));
 	}
 
+	/* MTU discovery */
+	widget = GTK_WIDGET (gtk_builder_get_object (builder, "mtu_disc_checkbutton"));
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
+		char *val = NULL;
+
+		combo = GTK_WIDGET (gtk_builder_get_object (builder, "mtu_disc_combo"));
+		switch (gtk_combo_box_get_active (GTK_COMBO_BOX (combo))) {
+		case 0:
+			val = "no";
+			break;
+		case 1:
+			val = "maybe";
+			break;
+		case 2:
+			val = "yes";
+			break;
+		}
+		if (val) {
+			g_hash_table_insert (hash,
+			                     g_strdup (NM_OPENVPN_KEY_MTU_DISC),
+			                     g_strdup (val));
+		}
+	}
+
 	return hash;
 }
 
