@@ -44,6 +44,7 @@
 #define INLINE_BLOB_PKCS12              "pkcs12"
 #define INLINE_BLOB_SECRET              "secret"
 #define INLINE_BLOB_TLS_AUTH            "tls-auth"
+#define INLINE_BLOB_TLS_CRYPT           "tls-crypt"
 
 const char *_nmovpn_test_temp_path = NULL;
 
@@ -925,6 +926,17 @@ do_import (const char *path, const char *contents, gsize contents_len, GError **
 			continue;
 		}
 
+		if (NM_IN_STRSET (params[0], NMV_OVPN_TAG_MTU_DISC)) {
+			if (!args_params_check_nargs_n (params, 1, &line_error))
+				goto handle_line_error;
+			if (!NM_IN_STRSET (params[1], "no", "maybe", "yes")) {
+				line_error = g_strdup_printf (_("unsupported mtu-disc argument"));
+				goto handle_line_error;
+			}
+			setting_vpn_add_data_item (s_vpn, NM_OPENVPN_KEY_MTU_DISC, params[1]);
+			continue;
+		}
+
 		if (NM_IN_STRSET (params[0], NMV_OVPN_TAG_NS_CERT_TYPE)) {
 			if (!args_params_check_nargs_n (params, 1, &line_error))
 				goto handle_line_error;
@@ -1155,7 +1167,8 @@ do_import (const char *path, const char *contents, gsize contents_len, GError **
 		                 NMV_OVPN_TAG_CERT,
 		                 NMV_OVPN_TAG_KEY,
 		                 NMV_OVPN_TAG_SECRET,
-		                 NMV_OVPN_TAG_TLS_AUTH)) {
+		                 NMV_OVPN_TAG_TLS_AUTH,
+		                 NMV_OVPN_TAG_TLS_CRYPT)) {
 			const char *file;
 			gs_free char *file_free = NULL;
 			gboolean can_have_direction;
@@ -1200,7 +1213,9 @@ do_import (const char *path, const char *contents, gsize contents_len, GError **
 				setting_vpn_add_data_item_path (s_vpn, NM_OPENVPN_KEY_TA, file);
 				if (s_direction)
 					setting_vpn_add_data_item (s_vpn, NM_OPENVPN_KEY_TA_DIR, s_direction);
-			} else
+			} else if (NM_IN_STRSET (params[0], NMV_OVPN_TAG_TLS_CRYPT))
+				setting_vpn_add_data_item_path (s_vpn, NM_OPENVPN_KEY_TLS_CRYPT, file);
+			else
 				g_assert_not_reached ();
 			continue;
 		}
@@ -1256,7 +1271,7 @@ do_import (const char *path, const char *contents, gsize contents_len, GError **
 		}
 
 		if (NM_IN_STRSET (params[0], NMV_OVPN_TAG_VERIFY_X509_NAME)) {
-			const char *type = "subject";
+			const char *type = NM_OPENVPN_VERIFY_X509_NAME_TYPE_SUBJECT;
 			gs_free char *item = NULL;
 
 			if (!args_params_check_nargs_minmax (params, 1, 2, &line_error))
@@ -1387,6 +1402,7 @@ do_import (const char *path, const char *contents, gsize contents_len, GError **
 			gs_free char *end_token = NULL;
 			gsize end_token_len;
 			gsize my_contents_cur_line = contents_cur_line;
+			gboolean is_base64 = FALSE;
 			char *f_path;
 			const char *key;
 			gboolean can_have_direction = FALSE;
@@ -1399,8 +1415,11 @@ do_import (const char *path, const char *contents, gsize contents_len, GError **
 				key = NM_OPENVPN_KEY_CERT;
 			else if (nm_streq (token, INLINE_BLOB_KEY))
 				key = NM_OPENVPN_KEY_KEY;
-			else if (nm_streq (token, INLINE_BLOB_PKCS12))
+			else if (nm_streq (token, INLINE_BLOB_PKCS12)) {
+				is_base64 = TRUE;
 				key = NULL;
+			} else if (nm_streq (token, INLINE_BLOB_TLS_CRYPT))
+				key = NM_OPENVPN_KEY_TLS_CRYPT;
 			else if (nm_streq (token, INLINE_BLOB_TLS_AUTH)) {
 				key = NM_OPENVPN_KEY_TA;
 				can_have_direction = TRUE;
@@ -1442,6 +1461,15 @@ do_import (const char *path, const char *contents, gsize contents_len, GError **
 				goto handle_line_error;
 			}
 
+			if (is_base64) {
+				gs_free guint8 *d = NULL;
+				gsize l;
+
+				d = g_base64_decode (blob_data->str, &l);
+				g_string_truncate (blob_data, 0);
+				g_string_append_len (blob_data, (const char *) d, l);
+			}
+
 			/* the latest cert wins... */
 			for (sl_iter = inline_blobs; sl_iter; sl_iter = sl_iter->next) {
 				InlineBlobData *d = sl_iter->data;
@@ -1882,6 +1910,8 @@ do_export_create (NMConnection *connection, const char *path, GError **error)
 	else if (value)
 		args_write_line_setting_value_int (f, NMV_OVPN_TAG_MSSFIX, s_vpn, NM_OPENVPN_KEY_MSSFIX);
 
+	args_write_line_setting_value (f, NMV_OVPN_TAG_MTU_DISC, s_vpn, NM_OPENVPN_KEY_MTU_DISC);
+
 	args_write_line_setting_value_int (f, NMV_OVPN_TAG_TUN_MTU, s_vpn, NM_OPENVPN_KEY_TUNNEL_MTU);
 
 	args_write_line_setting_value_int (f, NMV_OVPN_TAG_FRAGMENT, s_vpn, NM_OPENVPN_KEY_FRAGMENT_SIZE);
@@ -1924,7 +1954,7 @@ do_export_create (NMConnection *connection, const char *path, GError **error)
 	if (NM_IN_STRSET (connection_type,
 	                  NM_OPENVPN_CONTYPE_TLS,
 	                  NM_OPENVPN_CONTYPE_PASSWORD_TLS)) {
-		const char *x509_name, *ta_key;
+		const char *x509_name, *key;
 
 		args_write_line_setting_value (f, NMV_OVPN_TAG_REMOTE_CERT_TLS, s_vpn, NM_OPENVPN_KEY_REMOTE_CERT_TLS);
 		args_write_line_setting_value (f, NMV_OVPN_TAG_NS_CERT_TYPE, s_vpn, NM_OPENVPN_KEY_NS_CERT_TYPE);
@@ -1945,15 +1975,23 @@ do_export_create (NMConnection *connection, const char *path, GError **error)
 			args_write_line (f, NMV_OVPN_TAG_VERIFY_X509_NAME, name, type);
 		}
 
-		ta_key = nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_TA);
-		if (_arg_is_set (ta_key)) {
+		key = nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_TA);
+		if (_arg_is_set (key)) {
 			gs_free char *s_free = NULL;
-
 			args_write_line (f,
 			                 NMV_OVPN_TAG_TLS_AUTH,
-			                 nmv_utils_str_utf8safe_unescape_c (ta_key, &s_free),
+			                 nmv_utils_str_utf8safe_unescape_c (key, &s_free),
 			                 _arg_is_set (nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_TA_DIR)));
 		}
+
+		key = nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_TLS_CRYPT);
+		if (_arg_is_set (key)) {
+			gs_free char *s_free = NULL;
+			args_write_line (f,
+			                 NMV_OVPN_TAG_TLS_CRYPT,
+			                 nmv_utils_str_utf8safe_unescape_c (key, &s_free));
+		}
+
 	}
 
 	proxy_type = nm_setting_vpn_get_data_item (s_vpn, NM_OPENVPN_KEY_PROXY_TYPE);
@@ -2093,4 +2131,3 @@ do_export (const char *path, NMConnection *connection, GError **error)
 
 	return TRUE;
 }
-
